unit Oradoc_login;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  TFlatGroupBoxUnit, StdCtrls, TFlatComboBoxUnit, TFlatEditUnit,
  TFlatButtonUnit;

const MaxLogs = 1000;

type
  TFRMLOGIN = class(TForm)
    L_USERNAME: TLabel;
    L_PASSWORD: TLabel;
    L_DATABASE: TLabel;
    L_HISTORY: TLabel;
    FEUserName: TFlatEdit;
    FEPassword: TFlatEdit;
    FEDatabase: TFlatEdit;
    FCBHistory: TFlatComboBox;
    FGBLine: TFlatGroupBox;
    FBtnOk: TFlatButton;
    FBtnCancel: TFlatButton;
    procedure FormShow(Sender: TObject);
    procedure FCBHistoryChange(Sender: TObject);
    procedure FBtnOkClick(Sender: TObject);
    procedure FBtnCancelClick(Sender: TObject);
    procedure FEPasswordKeyPress(Sender: TObject; var Key: Char);
    procedure FEDatabaseKeyPress(Sender: TObject; var Key: Char);
    procedure FEUserNameKeyPress(Sender: TObject; var Key: Char);
    procedure FCBHistoryKeyPress(Sender: TObject; var Key: Char);
    procedure FCBHistoryKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
  private
    { Private declarations }
    szFilename: String;
    array_previous: array [1..MaxLogs, 1..2] of string;
    array_last: array [1..2] of string;
    procedure LoadHistory;
    procedure setLatest;
    procedure setHistory;
    procedure ClearArrays;
    procedure MakeHistoryFile(iRemoved: Integer);
    procedure AddNewLog;
  public
    { Public declarations }
    procedure setHistoryFile(Filename: String);
    procedure Login(szDatabase, szUser, szPassword: String);
  end;

var
  FRMLOGIN: TFRMLOGIN;

implementation

{$R *.DFM}

uses Oradoc_lib, oradoc_datamodule;

procedure TFRMLOGIN.setHistoryFile(Filename: String);
begin
    szFilename := Filename;
end;

procedure TFRMLOGIN.LoadHistory;
var tfFile: TextFile;
    szText, szPartOfText: String;
    BPrevious, BLast: Boolean;
    iI, iJ: Integer;
begin
    if FileExists(szFilename) then
    begin
    BPrevious := false;
    BLast := false;
    Assignfile(tfFile, szFilename);
    try
        reset(tfFile);
        try
        iI := 0;
        while not eof(tfFile) do
            begin
                readln(tfFile, szText);

                if BLast then
                begin
                    iJ := 1;
                    while szText <> '' do
                    begin
                        szPartOfText := copy(szText, 0,pos(';', szText)-1);
                        array_last[iJ] := szPartOfText;
                        szText := copy(szText, pos(';', szText) + 1, length(szText) - pos(';', szText));
                        inc(iJ);
                    end;
                    BLast := false;
                end;

                if ansicomparestr(szText, Oradoc_lib.DBLOGLAST) = 0 then
                    begin
                        BLast := true;
                        BPrevious := false;
                    end;

                if BPrevious then
                begin
                    inc(iI);
                    iJ := 1;
                    while szText <> '' do
                    begin
                        szPartOfText := copy(szText, 0,pos(';', szText)-1);
                        array_previous[iI,iJ] := szPartOfText;
                        szText := copy(szText, pos(';', szText) + 1, length(szText) - pos(';', szText));
                        inc(iJ);
                    end;
                    BPrevious := false;
                end;

                if ansicomparestr(szText, Oradoc_lib.DBLOGPREVIOUS) = 0 then
                    begin
                        BPrevious := true;
                    end;
            end;
        finally
            closefile(tfFile);
        end;
    except
        MessageDlg(Format(Oradoc_lib.DBLOGOPENERROR, [szFileName]), mtError, [mbOK], 0);
    end
    end;
end;

procedure TFRMLOGIN.setLatest;
begin
    if (array_last[1] <> '') and
       (array_last[2] <> '') then
        begin
        FEDatabase.text := array_last[1];
        FEUserName.Text := array_last[2];
        FEPassword.Text := '';
        if FEUserName.text <> '' then FEPassword.setfocus
        else FEUserName.setfocus
        end;
end;

procedure TFRMLOGIN.setHistory;
var iI: Integer;
begin
    iI := 1;
    FCBHistory.Items.Clear;
    while array_previous[iI, 1] <> '' do
    begin
        FCBHistory.Items.add(array_previous[iI, 1] + ' - ' +
            array_previous[iI, 2]);
        inc(iI);
    end;
end;

procedure TFRMLOGIN.ClearArrays;
var iI, iJ: Integer;
begin
    for iI := 1 to MaxLogs do
        for iJ := 1 to 2 do array_previous[iI, iJ] := '';

     for iI := 1 to 2 do array_last[iI] := '';
end;

procedure TFRMLOGIN.MakeHistoryFile(iRemoved: Integer);
var tfFile: TextFile;
    iI: Integer;
begin
    AssignFile(tfFile, szFilename);
    try
        rewrite(tfFile);
        try
            writeln(tfFile, Oradoc_lib.DBLOGPREVIOUS);
            iI := 1;
            while array_previous[iI,1] <> '' do
            begin
                if iRemoved + 1 <> iI then
                    writeln(tfFile, array_previous[iI, 1] + ';' +
                        array_previous[iI, 2] + ';');
          //              array_previous[iI, 3] + ';');
                inc(iI);
            end;
            writeln(tfFile, Oradoc_lib.DBLOGLAST);
            writeln(tfFile, FEDatabase.text + ';' +
                FEUserName.text + ';');
          //      FEPassword.text + ';');
        finally
            closefile(tfFile);
        end;
    except
        MessageDlg(Format(Oradoc_lib.DBLOGCREATEERROR, [szFileName]), mtError, [mbOK], 0);
    end;
end;

procedure TFRMLOGIN.AddNewLog;
var iI :Integer;
    BInList: Boolean;
begin
    iI := 1;
    BInList := false;
    while (array_previous[iI,1] <> '') do
    begin
        if (ansicomparestr(array_previous[iI,1], FEDatabase.text) = 0) and
           (ansicomparestr(array_previous[iI,2], FEUserName.text) = 0) then
           //(ansicomparestr(array_previous[iI,3], FEPassword.text) = 0) then
           BInList := true;
        inc(iI);
    end;
    if not BInList then
    begin
        array_previous[iI, 1] := FEDatabase.text;
        array_previous[iI, 2] := FEUserName.text;
        //array_previous[iI, 3] := FEPassword.text;
    end;
end;

procedure TFRMLOGIN.FormShow(Sender: TObject);
begin
    ClearArrays;
    LoadHistory;
    setLatest;
    setHistory;
end;

procedure TFRMLOGIN.FCBHistoryChange(Sender: TObject);
begin
    if FCBHistory.Text <> '' then
        begin
        FEDatabase.text := array_previous[FCBHistory.Items.IndexOf(FCBHistory.Text)+1, 1];
        FEUserName.Text := array_previous[FCBHistory.Items.IndexOf(FCBHistory.Text)+1, 2];
        FEPassword.Text := ''; //array_previous[FCBHistory.Items.IndexOf(FCBHistory.Text)+1, 3];
        end;
end;

procedure TFRMLOGIN.Login(szDatabase, szUser, szPassword: String);
begin
    DMODD.OCIDatabase.Close;
    DMODD.OCIDatabase.ServerName := szDatabase;
    DMODD.OCIDatabase.UserName := szUser;
    DMODD.OCIDatabase.Password := szPassword;
    DMODD.OCIDatabase.Open;
end;

procedure TFRMLOGIN.FBtnOkClick(Sender: TObject);
begin
    if FEUserName.text = '' then
    begin
        MessageDlg(Oradoc_lib.NOUSER, mtInformation, [mbOK], 0);
        FEUserName.SetFocus;
        exit;
    end;

    if FEPassword.text = '' then
    begin
        MessageDlg(Oradoc_lib.NOPASSWORD, mtInformation, [mbOK], 0);
        FEPassword.SetFocus;
        exit;
    end;

    if FEDatabase.text = '' then
    begin
        MessageDlg(Oradoc_lib.NODATABASE, mtInformation, [mbOK], 0);
        FEDatabase.SetFocus;
        exit;
    end;

    Login(FEDatabase.text, FEUserName.text, FEPassword.text);

    if DMODD.OCIDatabase.Connected then
    begin
        AddNewLog;
        MakeHistoryFile(-1);
        ModalResult := mrOK;
    end;
end;


procedure TFRMLOGIN.FBtnCancelClick(Sender: TObject);
begin
    ModalResult := mrCancel;
end;

procedure TFRMLOGIN.FEPasswordKeyPress(Sender: TObject; var Key: Char);
begin
    if (key = #13) or (key = #10) then
        begin
        key := #0;
        FBtnOk.click
        end;
end;

procedure TFRMLOGIN.FEDatabaseKeyPress(Sender: TObject; var Key: Char);
begin
    if (key = #13) or (key = #10) then
        begin
        key := #0;
        FBtnOk.click
        end;
end;

procedure TFRMLOGIN.FEUserNameKeyPress(Sender: TObject; var Key: Char);
begin
    if (key = #13) or (key = #10) then
        begin
        key := #0;
        FBtnOk.click
        end;
end;

procedure TFRMLOGIN.FCBHistoryKeyPress(Sender: TObject; var Key: Char);
begin
    key := #0;
end;

procedure TFRMLOGIN.FCBHistoryKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
var iRemoved: Integer;
begin
    if key = 46 then
    begin
        iRemoved := FCBHistory.Items.IndexOf(FCBHistory.Text);
        FCBHistory.text := '';
        MakeHistoryFile(iRemoved);
        FCBHistory.Items.Delete(iRemoved);
        ClearArrays;
        LoadHistory;
        setLatest;
        setHistory;
    end
end;

end.
